# vivplots
This repository holds the `pip` package for vivplots which holds common functions
for vivent graphs.

![unit tests](https://github.com/vivent-sarl/vivplots/actions/workflows/main.yml/badge.svg)

## Installing the package
This package can be installed directly using `pip` using the following commands:
```
pip install vivplots
```
